<?php
/**
 * Admin Helper class.
 *
 * @package BuddyPress Friendship Restrictions
 * @subpackage Admin
 * @copyright  Copyright (c) 2018, BuddyDev
 */

namespace BP_Friendship_Restrictions\Admin;

// Exit if file accessed directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Press_Themes\PT_Settings\Page;

/**
 * Class Admin_Helper
 */
class Admin_Helper {

	/**
	 * Admin Menu slug
	 *
	 * @var string
	 */
	private $menu_slug;

	/**
	 * Used to keep a reference of the Page, It will be used in rendering the view.
	 *
	 * @var \Press_Themes\PT_Settings\Page
	 */
	private $page;

	/**
	 * The Constructor.
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup admin section
	 */
	private function setup() {
		$this->menu_slug = 'buddypress-friendship-restrictions-settings';

		add_action( 'admin_init', array( $this, 'init' ) );
		add_action( 'admin_menu', array( $this, 'add_menu' ) );
	}

	/**+
	 * Add Menu
	 */
	public function add_menu() {
		add_options_page(
			_x( 'Friendship Restrictions', 'Admin settings page title', 'buddypress-friendship-restrictions' ),
			_x( 'Friendship Restrictions', 'Admin settings menu label', 'buddypress-friendship-restrictions' ),
			'manage_options',
			$this->menu_slug,
			array( $this, 'render' )
		);
	}

	/**
	 * Show/render the setting page
	 */
	public function render() {
		$this->page->render();
	}

	/**
	 * Is it the setting page?
	 *
	 * @return bool
	 */
	private function needs_loading() {

		global $pagenow;

		// We need to load on options.php otherwise settings won't be registered.
		if ( 'options.php' === $pagenow ) {
			return true;
		}

		if ( isset( $_GET['page'] ) && $_GET['page'] === $this->menu_slug ) {
			return true;
		}

		return false;
	}

	/**
	 * Initialize the admin settings panel and fields
	 */
	public function init() {

		if ( ! $this->needs_loading() ) {
			return;
		}

		$defaults = bpf_restrictions_get_default_settings();

		$all_roles = bpf_restrictions_get_roles();

		$page = new Page( 'bp_friendship_restrictions_settings' );

		// General settings tab.
		$panel = $page->add_panel( 'general', _x( 'General', 'Admin settings panel title', 'buddypress-friendship-restrictions' ) );

		$request_panel = $panel->add_section( 'requestable_panel', _x( 'Request Restrictions: Receiver', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$request_panel->add_fields(
			array(
				array(
					'name'    => 'restrict_receiver',
					'label'   => __( 'Restrict who can be requested friendship?', 'buddypress-friendship-restrictions' ),
					'default' => $defaults['restrict_receiver'],
					'type'    => 'radio',
					'options' => array(
						1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
						0 => __( 'No', 'buddypress-friendship-restrictions' ),
					),
					'desc'    => __( 'Restrict the users who can be added as friend. If enabled, only allowed roles will be able to receive request.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'receiver_roles',
					'label'   => __( 'Only these roles can receive request.', 'buddypress-friendship-restrictions' ),
					'default' => $defaults['receiver_roles'],
					'options' => $all_roles,
					'type'    => 'multicheck',
					'desc'    => __( 'Restrict the users who can be added as friend. If enabled, only allowed roles will be able to receive request.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'invalid_receiver_message',
					'label'   => _x( 'Invalid Receiver message ', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['invalid_sender_message'],
					'desc'    => __( 'Notice shown to sender when they try to add someone who are not allowed to be requested friendship.', 'buddypress-friendship-restrictions' ),
				),
			)
		);

		$sender_panel = $panel->add_section( 'sender_panel', _x( 'Request Restrictions: Sender', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$sender_panel->add_fields(
			array(
				array(
					'name'    => 'restrict_sender',
					'label'   => __( 'Restrict who can add friend?', 'buddypress-friendship-restrictions' ),
					'default' => 0,
					'type'    => 'radio',
					'options' => array(
						1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
						0 => __( 'No', 'buddypress-friendship-restrictions' ),
					),
					'desc'    => __( 'Restrict the users who can add others as friend. If enabled, only allowed roles will be able to send friendship request.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'sender_roles',
					'label'   => __( 'Only these roles can send request.', 'buddypress-friendship-restrictions' ),
					'type'    => 'multicheck',
					'default' => $defaults['sender_roles'],
					'options' => $all_roles,
					'desc'    => __( 'Restrict the users who can add others as friend. If enabled, only allowed roles will be able to send request.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'invalid_sender_message',
					'label'   => _x( 'Notice shown to sender when they are not allowed to add friend', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['invalid_sender_message'],
				),
				array(
					'name'    => 'throttle_request',
					'label'   => __( 'Throttle Request?', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'default' => 0,
					'options' => array(
						1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
						0 => __( 'No', 'buddypress-friendship-restrictions' ),
					),
					'desc'    => __( 'Set time based limit for sending request. Only limited no. of requests can be sent during the specified time duration.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'request_threshold',
					'label'   => _x( 'How many friends request a user can send?', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'text',
					'default' => $defaults['request_threshold'],
					'desc'    => __( 'Zero means none.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'request_throttle_duration',
					'label'   => _x( 'During the time(In minutes)?', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'text',
					'default' => $defaults['request_throttle_duration'],
				),
				array(
					'name'    => 'request_threshold_reached_message',
					'label'   => _x( 'What Message you want to display if the user reaches the friends request limit?', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['request_threshold_reached_message'],
				),
			)
		);

		$friends_count_panel = $panel->add_section( 'friends_count_panel', _x( 'Friendship Restrictions', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$friends_count_panel->add_fields(
			array(
				array(
					'name'    => 'restrict_friends_count',
					'label'   => __( 'Restrict Maximum number of allowed friends?', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'default' => 0,
					'options' => array(
						1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
						0 => __( 'No', 'buddypress-friendship-restrictions' ),
					),
					'desc'    => __( 'If enabled, a user can not have more than allowed number of friends.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'allowed_friends_count',
					'label'   => __( 'How many friends a user can have?', 'buddypress-friendship-restrictions' ),
					'type'    => 'text',
					'default' => $defaults['allowed_friends_count'],
					'desc'    => __( 'Zero means none.', 'buddypress-friendship-restrictions' ),
				),
				array(
					'name'    => 'friends_count_criteria',
					'label'   => __( 'What will the friends count criteria?', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'options' => array(
						'friendship' => __( 'Approved Friends Count', 'buddypress-friendship-restrictions' ),
						'request'    => __( 'No. of Friends & Friendship Request Sent & Received', 'buddypress-friendship-restrictions' ),
					),
					'default' => $defaults['friends_count_criteria'],
				),
				array(
					'name'    => 'friends_limit_reached_sender_self_message',
					'label'   => _x( 'On Send Request, Notice to show when sender reaches their limit', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['friends_limit_reached_sender_self_message'],
				),
				array(
					'name'    => 'friends_limit_reached_sender_other_message',
					'label'   => _x( 'On Send Request, Notice to show when requested user reaches their limit', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['friends_limit_reached_sender_other_message'],
				),
				array(
					'name'    => 'friends_limit_reached_acceptor_self_message',
					'label'   => _x( 'On Accept request, Notice to show when user accepting the request reaches their limit?', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['friends_limit_reached_acceptor_self_message'],
				),
				array(
					'name'    => 'friends_limit_reached_acceptor_other_message',
					'label'   => _x( 'On Accept request, Notice to shown when the user requesting friendship reaches their limit?', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['friends_limit_reached_acceptor_other_message'],
				),
			)
		);


		$unfriend_panel = $panel->add_section( 'misc_panel', _x( 'Miscellaneous', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$unfriend_panel->add_fields(
			array(
				array(
					'name'    => 'disable_unfriending',
					'label'   => _x( 'Do not allow users to unfriend each other.', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'options' => array(
						1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
						0 => __( 'No', 'buddypress-friendship-restrictions' ),
					),
					'default' => $defaults['disable_unfriending'],
				),
				array(
					'name'    => 'unfriending_error_message',
					'label'   => _x( 'Notice shown when user tries to unfriend.', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'textarea',
					'default' => $defaults['unfriending_error_message'],
				),
			)
		);


		$advance_panel = $panel->add_section( 'advance_panel', _x( 'Advance', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$advance_panel->add_fields(
			array(
				array(
					'name'    => 'restrict_by',
					'label'   => _x( 'Enable advance restrictions rules?', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'options' => array(
						''            => __( 'No', 'buddypress-friendship-restrictions' ),
						'role'        => __( 'Yes, By Role', 'buddypress-friendship-restrictions' ),
						'member_type' => __( 'Yes, By Member Type', 'buddypress-friendship-restrictions' ),
					),
					'default' => $defaults['restrict_by'],
					'desc'    => __( 'If you enable the advance restriction rules, you can set the limits per role or member type.', 'buddypress-friendship-restrictions' ),
				),
				/*array(
					'name'    => 'multi_restriction_criteria',
					'label'   => _x( 'What if a user has multiple roles or member types.', 'Admin settings', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'options' => array(
						'max' => __( 'Use settings that allows most.', 'buddypress-friendship-restrictions' ),
						'min' => __( 'Use settings that allows least.', 'buddypress-friendship-restrictions' ),
					),
					'default' => $defaults['multi_restriction_criteria'],
				),*/
			)
		);

		// Save page for future reference.
		$this->page = $page;

		$current_restrict_by_type = bpf_restrictions_get_option( 'restrict_by' );

		if ( 'role' === $current_restrict_by_type ) {
			$this->add_role_based_settings();
		} elseif ( 'member_type' === $current_restrict_by_type ) {
			$this->add_member_type_based_settings();
		}

		do_action( 'bp_friendship_restrictions_admin_settings', $page );

		// allow enabling options.
		$page->init();
	}

	/**
	 * Add role based settings
	 */
	private function add_role_based_settings() {
		$roles = bpf_restrictions_get_roles();

		//unset( $roles['all'] );

		foreach ( $roles as $role => $role_name ) {
			if ( 'all' == $role ) {
				continue;
			}

			$this->add_role_panel( $this->page, $role, $role_name, $roles );
		}
	}

	/**
	 * Add role based settings
	 */
	private function add_member_type_based_settings() {
		$member_types = bp_get_member_types( array(), 'objects' );

		$all_types        = array();
		$all_types['all'] = __( 'All Members', 'buddypress-friendship-restrictions' );

		foreach ( $member_types as $member_type => $member_type_object ) {
			$all_types[ $member_type ] = $member_type_object->labels['singular_name'];
		}


		foreach ( $member_types as $member_type => $member_type_object ) {
			$this->add_member_type_panel( $this->page, $member_type, $member_type_object, $all_types );
		}
	}

	/**
	 * Add role panel
	 *
	 * @param Page   $page Page object.
	 * @param string $role role identifier 'subscriber'.
	 * @param string $label role label.
	 */
	private function add_role_panel( $page, $role, $label, $all_roles ) {
		$panel = $page->add_panel( $role . 'role-panel', $label, sprintf( __( 'Restrictions for role: %s', 'buddypress-friendship-restrictions' ), $label ) );

		$general_section = $panel->add_section( $role . '-role-general', _x( 'Enable/Disable', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$general_section->add_fields(
			array(
				array(
					'name'    => 'enable_custom_settings_role_' . $role,
					'label'   => __( 'Enable custom settings for this role?', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'default' => 0,
					'options' => array(
						1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
						0 => __( 'No', 'buddypress-friendship-restrictions' ),
					),
					'desc'    => __( 'If set to "yes", you can customize the restrictions here. If set "no", the general restrictions will apply.', 'buddypress-friendship-restrictions' ),
				),
			)
		);
		$request_section = $panel->add_section( $role . '-role-friendship_request-send', _x( 'Request Restrictions: sending', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$default   = bpf_restrictions_get_default_settings();

		$fields = array(

			array(
				'name'    => 'restrict_sending_role_' . $role,
				'label'   => __( 'Restrict Sending request by this role?', 'buddypress-friendship-restrictions' ),
				'default' => 0,
				'type'    => 'radio',
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'Restrict if users with this role can add others as friend.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'sending_allowed_roles_role_' . $role,
				'label'   => __( 'Which roles can receive request.', 'buddypress-friendship-restrictions' ),
				'type'    => 'multicheck',
				'default' => $default['sender_roles'],
				'options' => $all_roles,
				'desc'    => __( 'Restrict the users who can be added as friend by users with this role. If enabled, only allowed roles will be able to send request.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'throttle_request_role_' . $role,
				'label'   => __( 'Throttle count?', 'buddypress-friendship-restrictions' ),
				'type'    => 'radio',
				'default' => $default['throttle_request'],
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'If set to no, Limit will not be consider when calculating role based user request threshold.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'request_threshold_role_' . $role,
				'label'   => _x( 'How many friends request can send?', 'Admin settings', 'buddypress-friendship-restrictions' ),
				'type'    => 'text',
				'default' => $default['request_threshold'],
				'desc'    => __( 'Zero means none.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'request_throttle_duration_role_' . $role,
				'label'   => _x( 'During the time(In minutes)?', 'Admin settings', 'buddypress-friendship-restrictions' ),
				'type'    => 'text',
				'default' => $default['request_throttle_duration'],
			),
		);

		$request_section->add_fields( $fields );


		$request_section_receiving = $panel->add_section( $role . '-role-friendship_request_receive', _x( 'Request Restrictions: Receiving', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$fields = array(

			array(
				'name'    => 'restrict_receiving_role_' . $role,
				'label'   => __( 'Restrict receiving request by this role?', 'buddypress-friendship-restrictions' ),
				'default' => 0,
				'type'    => 'radio',
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'Restrict if users with this role can receive friendship request from others.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'receiving_allowed_roles_role_' . $role,
				'label'   => __( 'Which roles can send request.', 'buddypress-friendship-restrictions' ),
				'type'    => 'multicheck',
				'default' => $default['sender_roles'],
				'options' => $all_roles,
				'desc'    => __( 'Restrict the users who can add users with this role as friend. If enabled, only allowed roles will be able to send request.', 'buddypress-friendship-restrictions' ),
			),
		);

		$request_section_receiving->add_fields( $fields );

		$friend_count_section = $panel->add_section( $role . '-role-friendship_count', _x( 'Settings for friendship count', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$fields = array(
			array(
				'name'    => 'restrict_friends_count_role_' . $role,
				'label'   => __( 'Restrict Maximum number of allowed friends?', 'buddypress-friendship-restrictions' ),
				'type'    => 'radio',
				'default' => $default['restrict_friends_count'],
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'If enabled, Allowed friends count will be considered when calculating role based friends count.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'allowed_friends_count_role_' . $role,
				'label'   => __( 'How many friends can have?', 'buddypress-friendship-restrictions' ),
				'type'    => 'text',
				'default' => $default['allowed_friends_count'],
				'desc'    => __( 'Zero means none.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'friends_count_criteria_role_' . $role,
				'label'   => __( 'What will the friends count criteria?', 'buddypress-friendship-restrictions' ),
				'type'    => 'radio',
				'options' => array(
					'friendship' => __( 'Approved Friends Count', 'buddypress-friendship-restrictions' ),
					'request'    => __( 'No. of Friends & Friendship Request Sent & Received', 'buddypress-friendship-restrictions' ),
				),
				'default' => $default['friends_count_criteria'],
			),
		);

		$friend_count_section->add_fields( $fields );
	}

	/**
	 * Add panel for member type.
	 *
	 * @param Page $page page object.
	 * @param string    $member_type member type.
	 * @param \stdClass $mtp_object array of member types.
	 * @param array     $all array of all member types(key=>label).
	 */
	private function add_member_type_panel( $page, $member_type, $mtp_object, $all ) {
		$label = $mtp_object->labels['singular_name'];

		$panel           = $page->add_panel( $member_type . '-mtype-panel', $label, sprintf( __( 'Restrictions for role: %s', 'buddypress-friendship-restrictions' ), $label ) );
		$general_section = $panel->add_section( $member_type . '-mtype-general', _x( 'Enable/Disable', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$general_section->add_fields(
			array(
				array(
					'name'    => 'enable_custom_settings_mtype_' . $member_type,
					'label'   => __( 'Enable custom settings for this member type?', 'buddypress-friendship-restrictions' ),
					'type'    => 'radio',
					'default' => 0,
					'options' => array(
						1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
						0 => __( 'No', 'buddypress-friendship-restrictions' ),
					),
					'desc'    => __( 'If set to "yes", you can customize the restrictions here. If set "no", the general restrictions will apply.', 'buddypress-friendship-restrictions' ),
				),
			)
		);

		$request_section = $panel->add_section( $member_type . '-mtype-friendship_request', _x( 'Settings for friendship request', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$default = bpf_restrictions_get_default_settings();

		$fields = array(
			array(
				'name'    => 'restrict_sending_mtype_' . $member_type,
				'label'   => __( 'Restrict Sending request by this member type?', 'buddypress-friendship-restrictions' ),
				'default' => 0,
				'type'    => 'radio',
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'Restrict if users with this member type can add others as friend.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'sending_allowed_member_types_mtype_' . $member_type,
				'label'   => __( 'Which member types can receive request.', 'buddypress-friendship-restrictions' ),
				'type'    => 'multicheck',
				'default' => $default['sender_member_types'],
				'options' => $all,
				'desc'    => __( 'Restrict the users who can be added as friend by users with this member type. If enabled, only allowed member types will be able to send request.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'throttle_request_mtype_' . $member_type,
				'label'   => __( 'Apply friendship request limit?', 'buddypress-friendship-restrictions' ),
				'type'    => 'radio',
				'default' => $default['throttle_request'],
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'If set to no, Limit will not be consider when calculating member type based user request threshold.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'request_threshold_mtype_' . $member_type,
				'label'   => _x( 'How many friends request can send?', 'Admin settings', 'buddypress-friendship-restrictions' ),
				'type'    => 'text',
				'default' => $default['request_threshold'],
				'desc'    => __( 'Zero means none.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'request_throttle_duration_mtype_' . $member_type,
				'label'   => _x( 'During the time(In minutes)?', 'Admin settings', 'buddypress-friendship-restrictions' ),
				'type'    => 'text',
				'default' => $default['request_throttle_duration'],
			),
		);

		$request_section->add_fields( $fields );


		$request_section_receiving = $panel->add_section( $member_type . '-mtype-friendship_request_receive', _x( 'Request Restrictions: Receiving', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$fields = array(

			array(
				'name'    => 'restrict_receiving_mtype_' . $member_type,
				'label'   => __( 'Restrict receiving request by this role?', 'buddypress-friendship-restrictions' ),
				'default' => 0,
				'type'    => 'radio',
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'Restrict if users with this role can receive friendship request from others.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'receiving_allowed_member_types_mtype_' . $member_type,
				'label'   => __( 'Which roles can send request.', 'buddypress-friendship-restrictions' ),
				'type'    => 'multicheck',
				'default' => $default['sender_member_types'],
				'options' => $all,
				'desc'    => __( 'Restrict the users who can add users with this member type as friend. If enabled, only allowed member types will be able to send request.', 'buddypress-friendship-restrictions' ),
			),
		);

		$request_section_receiving->add_fields( $fields );

		$friend_count_section = $panel->add_section( $member_type . '-mtype-friendship_count', _x( 'Settings for friendship count', 'Admin settings section title', 'buddypress-friendship-restrictions' ) );

		$fields = array(
			array(
				'name'    => 'restrict_friends_count_mtype_' . $member_type,
				'label'   => __( 'Restrict maximum number of allowed friends?', 'buddypress-friendship-restrictions' ),
				'type'    => 'radio',
				'default' => $default['restrict_friends_count'],
				'options' => array(
					1 => __( 'Yes', 'buddypress-friendship-restrictions' ),
					0 => __( 'No', 'buddypress-friendship-restrictions' ),
				),
				'desc'    => __( 'If enabled, Allowed friends count will be considered when calculating role based friends count.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'allowed_friends_count_mtype_' . $member_type,
				'label'   => __( 'How many friends can have?', 'buddypress-friendship-restrictions' ),
				'type'    => 'text',
				'default' => $default['allowed_friends_count'],
				'desc'    => __( 'Zero means none.', 'buddypress-friendship-restrictions' ),
			),
			array(
				'name'    => 'friends_count_criteria_mtype_' . $member_type,
				'label'   => __( 'What will the friends count criteria?', 'buddypress-friendship-restrictions' ),
				'type'    => 'radio',
				'options' => array(
					'friendship' => __( 'Approved Friends Count', 'buddypress-friendship-restrictions' ),
					'request'    => __( 'No. of Friends & Friendship Request Sent & Received', 'buddypress-friendship-restrictions' ),
				),
				'default' => $default['friends_count_criteria'],
			),
		);

		$friend_count_section->add_fields( $fields );
	}
}
