<?php
namespace BP_Friendship_Restrictions\Core;

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Check restrictions by role
 *
 * Class BPF_Restrictions_Member_Type
 */
class Restrictions_Member_Type {

	/**
	 * Is valid receiver.
	 *
	 * @param int  $user_id user id.
	 * @param int  $friend_id friend user id.
	 * @param bool $is_valid is valid.
	 *
	 * @return bool
	 */
	public function is_valid_sender( $user_id, $friend_id, $is_valid ) {
		$user = get_user_by( 'id', $user_id );

		if ( ! $user ) {
			return $is_valid;
		}

		$member_types = bp_get_member_type( $user_id, false );

		foreach ( $member_types as $member_type ) {
			if ( ! $this->is_enabled( $member_type ) ) {
				continue;
			}
			// if not restricted, allow.
			if ( ! bpf_restrictions_get_option( 'restrict_sending_mtype_' . $member_type ) ) {
				return true;
			}

			// if we are here, restriction is enabled.
			// check if allowed.
			// does the friend user has a role where we can send request.
			if ( $friend_id && bpf_restrictions_user_has_member_type_in( $friend_id, bpf_restrictions_get_option( 'sending_allowed_member_types_mtype_' . $member_type ) ) ) {
				return true;
			}

			$is_valid = false;
		}

		return $is_valid;
	}

	/**
	 * Is valid sender?
	 *
	 * @param int  $receiver_user_id user id.
	 * @param int  $sender_id sender user id.
	 * @param bool $is_valid is valid.
	 *
	 * @return bool
	 */
	public function is_valid_receiver( $receiver_user_id, $sender_id, $is_valid ) {
		$user = get_user_by( 'id', $receiver_user_id );

		if ( ! $user ) {
			return $is_valid;
		}

		$member_types = bp_get_member_type( $receiver_user_id, false );

		foreach ( $member_types as $member_type ) {
			if ( ! $this->is_enabled( $member_type ) ) {
				continue;
			}
			// if not restricted, allow.
			if ( ! bpf_restrictions_get_option( 'restrict_receiving_mtype_' . $member_type ) ) {
				return true;
			}

			// if we are here, restriction is enabled.
			// check if allowed.
			// does the friend user has a role from which we can receive request.
			if ( $sender_id && bpf_restrictions_user_has_member_type_in( $sender_id, bpf_restrictions_get_option( 'receiving_allowed_member_types_mtype_' . $member_type ) ) ) {
				return true;
			}

			$is_valid = false;
		}

		return $is_valid;
	}

	/**
	 * Check if request limit reached.
	 *
	 * @param int  $user_id user id.
	 * @param bool $has_reached has reached limit.
	 *
	 * @return bool
	 */
	public function has_reached_request_threshold( $user_id, $has_reached ) {

		if ( is_super_admin( $user_id ) ) {
			return $has_reached;
		}

		$user = get_user_by( 'id', $user_id );

		if ( ! $user ) {
			return $has_reached;
		}

		$member_types = bp_get_member_type( $user_id, false );

		foreach ( $member_types as $member_type ) {
			if ( ! $this->is_enabled( $member_type ) ) {
				continue;
			}
			// reset global.
			$has_reached = true;
			// if not throttled, allow.
			if ( ! bpf_restrictions_get_option( 'throttle_request_mtype_' . $member_type ) ) {
				$has_reached = false;
				break;
			}

			// check if reached.
			if ( bpf_restrictions_get_pending_sent_request_count_for_duration( $user_id, bpf_restrictions_get_option( 'request_throttle_duration_mtype_' . $member_type ) ) < bpf_restrictions_get_option( 'request_threshold_mtype_' . $member_type )  ) {
				$has_reached = false;
				break;
			}
		}

		return $has_reached;
	}

	/**
	 * Check if friendship limit reached.
	 *
	 * @param int  $user_id user id.
	 * @param bool $has_reached has reached limit.
	 *
	 * @return bool
	 */
	public function has_reached_friendship_limit( $user_id, $has_reached ) {

		if ( is_super_admin( $user_id ) ) {
			return $has_reached;
		}

		$user = get_user_by( 'id', $user_id );

		if ( ! $user ) {
			return $has_reached;
		}

		$total_friends_count   = friends_get_friend_count_for_user( $user_id );
		$pending_friends_count = bpf_restrictions_get_pending_request_count( $user_id );

		$member_types = bp_get_member_type( $user_id, false );

		foreach ( $member_types as $member_type ) {
			if ( ! $this->is_enabled( $member_type ) ) {
				continue;
			}

			// if not restricted, allow.
			if ( ! bpf_restrictions_get_option( 'restrict_friends_count_mtype_' . $member_type ) ) {
				return false;
			}

			$allowed_friends_count = bpf_restrictions_get_option( 'allowed_friends_count_mtype_' . $member_type );

			// User is super admin, there is no limit for them.
			if ( $allowed_friends_count <= 0 ) {
				$has_reached = true;
				continue;
			}

			$criteria      = bpf_restrictions_get_option( 'friends_count_criteria_mtype_' . $member_type );
			$current_total = $total_friends_count;

			if ( 'request' === $criteria ) {
				$current_total = $current_total + $pending_friends_count;
			}

			if ( $current_total < $allowed_friends_count ) {
				return false;
			}

			$has_reached = true;
		}

		return $has_reached;
	}


	/**
	 * Is custom config enabled for this member type.
	 *
	 * @param string $member_type member type.
	 *
	 * @return bool
	 */
	public function is_enabled( $member_type ) {
		return bpf_restrictions_get_option( 'enable_custom_settings_mtype_' . $member_type );
	}
}

