<?php
/**
 * Ajax handler
 *
 * @package    BP_Friendship_Restrictions
 * @subpackage Handlers
 * @copyright  Copyright (c) 2018, BuddyDev
 *
 * @author Ravi Sharma
 */

namespace BP_Friendship_Restrictions\Handlers;

// Exit if files accessed directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Ajax_Request_Handler
 */
class Ajax_Request_Handler {

	/**
	 * Boot class
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * The constructor.
	 */
	private function setup() {
		add_action( 'wp_ajax_addremove_friend', array( $this, 'addremove_friend' ), 5 );
		add_action( 'wp_ajax_accept_friendship', array( $this, 'on_ajax_accept' ), 5 );

		// Extended friendship request compatibility.
		add_action( 'wp_ajax_ext_friend_add_friend', array( $this, 'ext_add_remove_friend' ), 5 );

		// Add Nouveau compatibility.
		add_action( 'wp_ajax_friends_add_friend', array( $this, 'nouveau_addremove_friend' ), 5 );
		add_action( 'wp_ajax_friends_accept_friendship', array( $this, 'nouveau_gate_accept' ), 5 );
		add_action( 'wp_ajax_friends_remove_friend', array( $this, 'nouveau_addremove_friend' ), 5 );
	}

	/**
	 * Handle ajax action for legacy template.
	 */
	public function addremove_friend() {

		if ( is_super_admin() ) {
			return;
		}

		$friend_id = absint( $_POST['fid'] );

		$user = get_user_by( 'id', $friend_id );

		// invalid, let default handler deal with it.
		if ( ! $user ) {
			return;
		}

		$friend_status = bp_is_friend( $friend_id );

		// Is un-friending disabled?
		if ( 'is_friend' == $friend_status && bpf_restrictions_is_unfriending_disabled() ) {
			check_ajax_referer( 'friends_remove_friend' );
			$message = bpf_restrictions_get_option( 'unfriending_error_message' );

			// send the error message and die.
			echo "-1<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );
		}
		// must be add friend request.
		if ( 'not_friends' !== $friend_status ) {
			return;
		}

		// it is add friend request.
		check_ajax_referer( 'friends_add_friend' );

		$logged_id = bp_loggedin_user_id();

		if ( ! bpf_restrictions_user_is_valid_sender( $logged_id, $friend_id ) ) {
			// Restricted send for the user.
			$message = bpf_restrictions_get_option( 'invalid_sender_message' );
			echo "<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );

		} elseif ( ! bpf_restrictions_user_is_valid_receiver( $friend_id, $logged_id ) ) {
			// Restricted send for te
			$message = bpf_restrictions_get_option( 'invalid_receiver_message' );
			echo "<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );
		} elseif ( bpf_restrictions_user_reached_request_threshold( $logged_id ) ) {
			// if throttling is enabled and the logged user has reached limit, show error.
			// Restricted send for te
			$message = bpf_restrictions_get_option( 'request_threshold_reached_message' );
			echo "<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );
		}


		// check for friendship limit for both.
		if ( bpf_restrictions_user_reached_friendship_limit( $logged_id ) ) {
			$message = bpf_restrictions_get_option( 'friends_limit_reached_sender_self_message' );
			// send the error message and die.
			echo "<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );
		} elseif ( bpf_restrictions_user_reached_friendship_limit( $friend_id ) ) {
			$message = bpf_restrictions_get_option( 'friends_limit_reached_sender_other_message' );
			// send the error message and die.
			echo "<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );
		}
		// all is well if we reached here.
	}

	/**
	 * Gate friendship accept for nouveau.
	 */
	public function nouveau_gate_accept() {

		if ( ! function_exists( 'bp_nouveau' ) || ! isset( $_POST['nonce'] ) ) {
			return;
		}

		if ( is_super_admin() ) {
			return;
		}

		check_ajax_referer( 'bp_nouveau_friends', 'nonce' );

		$friend_id = absint( $_POST['item_id'] );

		// Friend id is friendship id in this case.
		$friendship = new \BP_Friends_Friendship( $friend_id, false, false );

		$initiator_user_id = $friendship->initiator_user_id;
		$friend_user_id    = $friendship->friend_user_id;

		if ( bpf_restrictions_user_reached_friendship_limit( $friend_user_id ) ) {
			wp_send_json_error(
				array(
					'feedback' => sprintf(
						'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
						bpf_restrictions_get_option( 'friends_limit_reached_acceptor_self_message' )
					),
				)
			);
		} elseif ( bpf_restrictions_user_reached_friendship_limit( $initiator_user_id ) ) {
			wp_send_json_error(
				array(
					'feedback' => sprintf(
						'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
						bpf_restrictions_get_option( 'friends_limit_reached_acceptor_other_message' )
					),
				)
			);
		}

	}

	/**
	 * Added nouveau compatibility
	 *
	 * @param string $action Nonce action.
	 */
	public function nouveau_addremove_friend( $action = 'bp_nouveau_friends' ) {

		if ( ! function_exists( 'bp_nouveau' ) || ! isset( $_POST['nonce'] ) ) {
			return;
		}

		if ( is_super_admin() ) {
			return;
		}

		// Make sure action have value.
		$action = empty( $action ) ? 'bp_nouveau_friends' : $action;

		check_ajax_referer( $action, 'nonce' );

		$friend_id = absint( $_POST['item_id'] );
		$user      = get_user_by( 'id', $friend_id );

		if ( ! $user ) {
			return;// invalid request.
		}

		$friend_status = bp_is_friend( $friend_id );

		if ( 'is_friend' === $friend_status && bpf_restrictions_is_unfriending_disabled() ) {
			wp_send_json_error(
				array(
					'feedback' => sprintf(
						'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
						bpf_restrictions_get_option( 'unfriending_error_message' )
					),
				)
			);
		} elseif ( 'not_friends' === $friend_status ) {
			// new friendship request.
			$logged_id = bp_loggedin_user_id();
			if ( ! bpf_restrictions_user_is_valid_sender( $logged_id, $friend_id ) ) {
				wp_send_json_error(
					array(
						'feedback' => sprintf(
							'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
							bpf_restrictions_get_option( 'invalid_sender_message' )
						),
					)
				);
			} elseif ( ! bpf_restrictions_user_is_valid_receiver( $friend_id, $logged_id ) ) {
				wp_send_json_error(
					array(
						'feedback' => sprintf(
							'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
							bpf_restrictions_get_option( 'invalid_receiver_message' )
						),
					)
				);
			} elseif ( bpf_restrictions_user_reached_request_threshold( $logged_id ) ) {
				// if throttling is enabled and the logged user has reached limit, show error.
				// Restricted send.
				wp_send_json_error(
					array(
						'feedback' => sprintf(
							'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
							bpf_restrictions_get_option( 'request_threshold_reached_message' )
						),
					)
				);
			}

			// if we are here, friendship limit is enabled, let us check for both.
			if ( bpf_restrictions_user_reached_friendship_limit( $logged_id ) ) {
				wp_send_json_error(
					array(
						'feedback' => sprintf(
							'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
							bpf_restrictions_get_option( 'friends_limit_reached_sender_self_message' )
						),
					)
				);
			} elseif ( bpf_restrictions_user_reached_friendship_limit( $friend_id ) ) {
				wp_send_json_error(
					array(
						'feedback' => sprintf(
							'<div class="bp-feedback error bp-ajax-message"><p>%s</p></div>',
							bpf_restrictions_get_option( 'friends_limit_reached_sender_other_message' )
						),
					)
				);
			}
		}
	}

	/**
	 * Extended friendship request.
	 */
	public function ext_add_remove_friend() {

		if ( function_exists( 'bp_nouveau' ) ) {
			$this->nouveau_addremove_friend( 'friends_add_friend' );
		} else {
			$this->addremove_friend();
		}
	}

	/**
	 * Check if we want to let the acceptance request succeed
	 */
	public function on_ajax_accept() {

		if ( is_super_admin() ) {
			return;
		}

		check_admin_referer( 'friends_accept_friendship' );

		$friendship_id = (int) $_POST['id'];

		$friendship = new \BP_Friends_Friendship( $friendship_id, false, false );

		$initiator_user_id = $friendship->initiator_user_id;
		$friend_user_id    = $friendship->friend_user_id;

		if ( bpf_restrictions_user_reached_friendship_limit( $friend_user_id ) ) {
			$message = bpf_restrictions_get_option( 'friends_limit_reached_acceptor_self_message' );
			// send the error message and die.
			echo "<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );
		} elseif ( bpf_restrictions_user_reached_friendship_limit( $initiator_user_id ) ) {
			$message = bpf_restrictions_get_option( 'friends_limit_reached_acceptor_other_message' );
			// send the error message and die.
			echo "<div id='message' class='error'><p>" . $message . '</p></div>';
			exit( 0 );
		}
	}
}
